module.exports = defineTest({
	description: 'avoids unnecessary deoptimizations of conditional expressions'
});
